@@ -1,5 +1,5 @@
 #
-# execute PHP buildin functions
+# execute PHP built-in functions
 #
 package PHP::Decode::Func;
 
@@ -3659,7 +3659,7 @@ without external side-effects.
 
 =head2 exec_cmd
 
-Execute a php buildin-function.
+Execute a php built-in function.
 
     $res = PHP::Decode::Func::exec_cmd($ctx, $cmd, $args);
 
