@@ -253,7 +253,7 @@ our @tests = (
 	'prec6',      q($x = 1 != 2),                     q($x = 1 ;),
 	'prec7',      q($x = 1 === 1),                    q($x = 1 ;),
 	'prec8',      q($x = a(); $x >>= 2),              q($x = a ( ) ; $x = $x >> 2 ;),
-	'prec9',      q($x = 8800000000 / 0x100000000),   q($x = 2.04890966415405 ;),
+	'prec9',      q($x = round(8800000000 / 0x100000000, 12);), q($x = 2.048909664154 ;),
 	'prec10',     q($x = (a() || !(b()));),           q($x = a ( ) || ! b ( ) ;),
 	'prec11',     q(if (f()) {$x = $a % $b == $c;}),  q(if ( f ( ) ) { $x = ( $a % $b ) == $c ; }),
 	'n:prec12',   q($x >>= 2),                        q($x = 0 ;),
